==> regina-normal_4.96.orig.tar.gz: regina-4.96/testsuite/exhaustive.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Test Suite                                                            *
 *                                                                        *
 *  Copyright (c) 1999-2014, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

#ifndef __EXHAUSTIVE_H
#define __EXHAUSTIVE_H

/**
 * The functions in this header allow you to run a test over all
 * triangulations from a census.  Each triangulation will have its
 * packet label set to its isomorphic signature (which may be useful for
 * any test failure messages).
 *
 * The \a small parameter indicates that a smaller census should be
 * used; this is appropriate when the corresponding test is extremely slow.
 */

namespace regina {
    class Dim2Triangulation;
    class NTriangulation;
}

typedef void (*Dim2TriangulationTestFunction)(regina::Dim2Triangulation*);
typedef void (*NTriangulationTestFunction)(regina::NTriangulation*);

void runCensusMinClosed(NTriangulationTestFunction f, bool small_ = false);
void runCensusAllClosed(NTriangulationTestFunction f, bool small_ = false);
void runCensusAllBounded(NTriangulationTestFunction f, bool small_ = false);
void runCensusAllIdeal(NTriangulationTestFunction f, bool small_ = false);
void runCensusAllNoBdry(NTriangulationTestFunction f, bool small_ = false);

#endif

==> regina-normal_5.0.orig.tar.gz: regina-5.0/testsuite/exhaustive.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Test Suite                                                            *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#ifndef __EXHAUSTIVE_H
#define __EXHAUSTIVE_H

/**
 * The functions in this header allow you to run a test over all
 * triangulations from a census.  Each triangulation will have its
 * packet label set to its isomorphic signature (which may be useful for
 * any test failure messages).
 *
 * The \a small parameter indicates that a smaller census should be
 * used; this is appropriate when the corresponding test is extremely slow.
 */

namespace regina {
    template <int> class Triangulation;
}

typedef void (*Dim2TriangulationTestFunction)(regina::Triangulation<2>*);
typedef void (*NTriangulationTestFunction)(regina::Triangulation<3>*);
typedef void (*Dim4TriangulationTestFunction)(regina::Triangulation<4>*);

void runCensusMinClosed(NTriangulationTestFunction f, bool small_ = false);
void runCensusAllClosed(NTriangulationTestFunction f, bool small_ = false);
void runCensusAllBounded(NTriangulationTestFunction f, bool small_ = false);
void runCensusAllIdeal(NTriangulationTestFunction f, bool small_ = false);
void runCensusAllNoBdry(NTriangulationTestFunction f, bool small_ = false);

void runCensusAllClosed(Dim4TriangulationTestFunction f);
void runCensusAllBounded(Dim4TriangulationTestFunction f);
void runCensusAllNoBdry(Dim4TriangulationTestFunction f);

#endif
